(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8925,        234]*)
(*NotebookOutlinePosition[     10699,        289]*)
(*  CellTagsIndexPosition[     10655,        285]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Introduction"]], "Title",
  CounterAssignments->{{"Title", 3}}],

Cell[TextData[StyleBox["The title of the present elaboration is:"]], "Text"],

Cell[TextData[StyleBox[
"Fractional Diffusion Equations and Fox's H-Functions\nwith Examples from \
Physics"]], "Text",
  TextAlignment->Center,
  FontSlant->"Italic"],

Cell[TextData[{
  StyleBox[
  "The fractional diffusion equations in very simple way describe the \
phenomenon of anonalous diffusion. In the one-dimensional form they represent \
a continuous transition (Schneider and Wyss "],
  ButtonBox["[SWy1989]",
    ButtonData:>{"Literatur.nb", "[SWy1989]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  ") between Fick's diffusion law and the wave equation by continuous change \
of the time derivative order. In this elaboration the importance of variance \
analysis concerning evaluation of physical measured data on diffusion is \
emphasized. The relation already given by A. Einstein on normal diffusion, \
during this elaboration is to be specified and to be generalized consistently \
for anomalous diffusion. For this there are preparations (West et al. "],
  ButtonBox["[WGMN1997]",
    ButtonData:>{"Literatur.nb", "[WGMN1997]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  "). The validity of Einstein's relation also for diffusive processes with \
final spreading speed is dealed with on the verge, too (chapter 1)."]
}], "Text"],

Cell[TextData[{
  StyleBox[
  "Fox's H-functions and their Fourier convolutions represent the solution \
space (Schneider and Wyss "],
  ButtonBox["[SWy1989]",
    ButtonData:>{"Literatur.nb", "[SWy1989]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  ") of the diffusion equations being dealed with here. Fox's H-functions \
(Dixon and Ferrar "],
  ButtonBox["[DF1936]",
    ButtonData:>{"Literatur.nb", "[DF1936]"},
    ButtonStyle->"Hyperlink"],
  StyleBox["; Fox "],
  ButtonBox["[Fox1961]",
    ButtonData:>{"Literatur.nb", "[Fox1961]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[") are described as Mellin Barnes integrals (Mellin "],
  ButtonBox["[Mel1910]; ",
    ButtonData:>{"Literatur.nb", "[Mel1910]"},
    ButtonStyle->"Hyperlink"],
  StyleBox["Barnes "],
  ButtonBox["[Bar1908]",
    ButtonData:>{"Literatur.nb", "[Bar1908]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  "), which can be dealed with analytically and numerically (Mathai and \
Saxena "],
  ButtonBox["[MS1978])",
    ButtonData:>{"Literatur.nb", "[MS1978]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  " comparatively well. Expansions of function theory are discussed, where \
this elaboration needs it (chapter 2)."]
}], "Text"],

Cell[TextData[{
  StyleBox[
  "For the analytical and numerical evaluation during this elaboration the \
computer algebra system "],
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  StyleBox[
  " plays an extraordinary part, where a computer algebra package named "],
  StyleBox["FractionalCalculus",
    FontSlant->"Italic"],
  StyleBox[" has been built up on purpose to do the huge calculation work."]
}], "Text"],

Cell[TextData[{
  StyleBox[
  "When solving time fractional diffusion equations, the solution by \
Schneider and Wyss [SWy1989] is to be verified and to be discussed especially \
for fractal space dimensions. The space fractional diffusion equation by \
Seshadri and West "],
  ButtonBox["[SWe1982]",
    ButtonData:>{"Literatur.nb", "[SWe1982]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  " is to be discussed, too.  Furthermore a normal distribution (Wei et al. \
"],
  ButtonBox["[WBL2000]",
    ButtonData:>{"Literatur.nb", "[WBL2000]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  ") with anomalous time depending variance is checked, whether it is based \
on a dynamic equation being physically easy to understand. In a consistently \
combined model of a time and space fractional diffusion equation a stable \
solution concerning variance is to be found (chapter 3)."]
}], "Text",
  PageBreakBelow->True],

Cell[TextData[StyleBox[
"Two application examples to the theoretical sketch of fractional diffusion \
equations shall be discussed. For this, the section Nuclear Resonance \
Spectroscopy at the University of Ulm, leaded by Mr. Professor Dr. R. \
Kimmich, and the research group Surface and Deep Temperature Physics of the \
Department for Physics at the University of Konstanz, leaded by Mr. Professor \
Dr. P. Leiderer, each kindly made available corresponding measured data for \
further evaluation. "]], "Text"],

Cell[TextData[{
  StyleBox[
  "The comparison to measured data, which is based on a diffusive process in \
a fractal space dimension, is to be done, where the measured data (Zavada and \
Kimmich "],
  ButtonBox["[ZK1998]",
    ButtonData:>{"Literatur.nb", "[ZK1998]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[") has given the occasion to a co-operation (Zavada et al. "],
  ButtonBox["[ZSKN1999]",
    ButtonData:>{"Literatur.nb", "[ZSKN1999]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  ") with the section Nuclear Resonance Spectroscopy. The unanswered \
questions to theoretical understanding of the doctoral thesis "],
  ButtonBox["[Zav1999]",
    ButtonData:>{"Literatur.nb", "[Zav1999]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[" by T. Zavada (Link) are to be cleared up (chapter 4)."]
}], "Text"],

Cell[TextData[{
  StyleBox["A further comparison to measured data (Wei et al. "],
  ButtonBox["[WBL2000]",
    ButtonData:>{"Literatur.nb", "[WBL2000]"},
    ButtonStyle->"Hyperlink"],
  StyleBox[
  ") of anomalous diffusion, which was recorded at the University of \
Konstanz, is to be done with the calculated propagator of the best fitting \
among the fractional diffusion equations and the normal distribution being \
modified concerning variance. The comparison needs a Fourier convolution, \
which in the corresponding context gives an alternative to Voigt's profiles \
concerning stability of variance (Kapitel 5)."]
}], "Text"],

Cell[TextData[{
  StyleBox[
  "The elaboration has been cared for scientifically by Mr. Professor Dr. T. \
F. Nonnenmacher. The program package "],
  StyleBox["FractionalCalculus",
    FontSlant->"Italic"],
  StyleBox[
  " has been designed in co-operation with Mr. Professor Dr. G. Baumann, who \
correctly emphasizes the importance of computer algebra for many fields of \
theoretical physics."]
}], "Text"],

Cell[TextData[{
  "In the course of this elaboration the presentation of the results being \
used within computer algebra (and a little bit needing habituation) is \
withdrawn. Merely the style of the function names in the form being used by \
the computer algebra system ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " (Wolfram ",
  ButtonBox["[Wol1997]",
    ButtonData:>{"Literatur.nb", "[Wol1997]"},
    ButtonStyle->"Hyperlink"],
  ") reminds, how all results pesented here have been checked by the author \
per machine and mostly also by hand of Mr. Professor Nonnenmacher."
}], "Text"],

Cell[TextData[StyleBox[
"In the appendices background information is found and mathematical aspects, \
which finish the understanding of the elaboration or enable an explicit \
reckoning over again."]], "Text"]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 742}},
ScreenStyleEnvironment->"Printout",
PrintingStyleEnvironment->"Printout",
ShowPageBreaks->True,
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{1248, 719},
WindowMargins->{{-4, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingStartingPageNumber->13,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {"Introduction"}], "Header"]}, {Cell[ 
        TextData[ {"Introduction"}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{72, 72}, {108, 72}},
"PaperSize"->{597.563, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FacingPages"->True,
"Magnification"->1},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
PrivateFontOptions->{"FontType"->"Outline"},
CharacterEncoding->"XAutomaticEncoding",
Magnification->1.5,
StyleDefinitions -> "TeX-German.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 87, 1, 109, "Title",
  CounterAssignments->{{"Title", 3}}],
Cell[1821, 54, 76, 0, 32, "Text"],
Cell[1900, 56, 167, 4, 52, "Text"],
Cell[2070, 62, 1083, 21, 172, "Text"],
Cell[3156, 85, 1212, 34, 112, "Text"],
Cell[4371, 121, 420, 11, 72, "Text"],
Cell[4794, 134, 915, 21, 132, "Text",
  PageBreakBelow->True],
Cell[5712, 157, 514, 7, 112, "Text"],
Cell[6229, 166, 811, 19, 92, "Text"],
Cell[7043, 187, 635, 12, 112, "Text"],
Cell[7681, 201, 409, 10, 72, "Text"],
Cell[8093, 213, 603, 13, 92, "Text"],
Cell[8699, 228, 210, 3, 52, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

